Support — boto v2.21.1

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.21.1 »

# Support

## boto.support

`boto.support.` `connect_to_region`(region_name, **kw_params)

`boto.support.` `regions`()

  Get all available regions for the Amazon Support service.

  Return type: | list
  Returns: | A list of `boto.regioninfo.RegionInfo`

## boto.support.layer1

class `boto.support.layer1.` `SupportConnection`(**kwargs)

  AWS Support The AWS Support API reference is intended for programmers who need detailed information about the AWS Support actions and data types. This service enables you to manage your AWS Support cases programmatically. It uses HTTP methods that return results in JSON format.

  The AWS Support service also exposes a set of `Trusted Advisor`_ features. You can retrieve a list of checks you can run on your resources, specify checks to run and refresh, and check the status of checks you have submitted.

  The following list describes the AWS Support case management actions:

  - **Service names, issue categories, and available severity levels. **The actions `DescribeServices`_ and `DescribeSeverityLevels`_ enable you to obtain AWS service names, service codes, service categories, and problem severity levels. You use these values when you call the `CreateCase`_ action.
  - Case Creation, case details, and case resolution. The actions `CreateCase`_, `DescribeCases`_, and `ResolveCase`_ enable you to create AWS Support cases, retrieve them, and resolve them.
  - Case communication. The actions `DescribeCommunications`_ and `AddCommunicationToCase`_ enable you to retrieve and add communication to AWS Support cases.

  The following list describes the actions available from the AWS Support service for Trusted Advisor:

  - `DescribeTrustedAdvisorChecks`_ returns the list of checks that you can run against your AWS resources.
  - Using the CheckId for a specific check returned by DescribeTrustedAdvisorChecks, you can call `DescribeTrustedAdvisorCheckResult`_ and obtain a new result for the check you specified.
  - Using `DescribeTrustedAdvisorCheckSummaries`_, you can get summaries for a set of Trusted Advisor checks.
  - `RefreshTrustedAdvisorCheck`_ enables you to request that Trusted Advisor run the check again.
  - `DescribeTrustedAdvisorCheckRefreshStatuses`_ gets statuses on the checks you are running.

  For authentication of requests, the AWS Support uses `Signature Version 4 Signing Process`_.

  See the AWS Support `Developer Guide`_ for information about how to use this service to manage create and manage your support cases, and how to call Trusted Advisor for results of checks on your resources.

  `APIVersion` = '2013-04-15'
  `DefaultRegionEndpoint` = 'support.us-east-1.amazonaws.com'
  `DefaultRegionName` = 'us-east-1'
  `ResponseError`

    alias of `JSONResponseError`

  `ServiceName` = 'Support'
  `TargetPrefix` = 'AWSSupport_20130415'
  `add_communication_to_case`(communication_body, case_id=None, cc_email_addresses=None)

    This action adds additional customer communication to an AWS Support case. You use the CaseId value to identify the case to which you want to add communication. You can list a set of email addresses to copy on the communication using the CcEmailAddresses value. The CommunicationBody value contains the text of the communication.

    This action’s response indicates the success or failure of the request.

    This action implements a subset of the behavior on the AWS Support `Your Support Cases`_ web form.

    Parameters: | case_id (string) – String that indicates the AWS Support caseID requested or returned in the call. The caseID is an alphanumeric string formatted as shown in this example CaseId: case-12345678910-2013-c4c1d2bf33c5cf47 communication_body (string) – Represents the body of an email communication added to the support case. cc_email_addresses (list) – Represents any email addresses contained in the CC line of an email added to the support case.

  `create_case`(subject, communication_body, service_code=None, severity_code=None, category_code=None, cc_email_addresses=None, language=None, issue_type=None)

    Creates a new case in the AWS Support Center. This action is modeled on the behavior of the AWS Support Center `Open a new case`_ page. Its parameters require you to specify the following information:

    1. ServiceCode. Represents a code for an AWS service. You obtain the ServiceCode by calling `DescribeServices`_.
    2. CategoryCode. Represents a category for the service defined for the ServiceCode value. You also obtain the cateogory code for a service by calling `DescribeServices`_. Each AWS service defines its own set of category codes.
    3. SeverityCode. Represents a value that specifies the urgency of the case, and the time interval in which your service level agreement specifies a response from AWS Support. You obtain the SeverityCode by calling `DescribeSeverityLevels`_.
    4. Subject. Represents the Subject field on the AWS Support Center `Open a new case`_ page.
    5. CommunicationBody. Represents the Description field on the AWS Support Center `Open a new case`_ page.
    6. Language. Specifies the human language in which AWS Support handles the case. The API currently supports English and Japanese.
    7. CcEmailAddresses. Represents the AWS Support Center CC field on the `Open a new case`_ page. You can list email addresses to be copied on any correspondence about the case. The account that opens the case is already identified by passing the AWS Credentials in the HTTP POST method or in a method or function call from one of the programming languages supported by an `AWS SDK`_.
    8. IssueType. Indicates the type of issue for the case. You can specify either “customer-service” or “technical.” If you do not indicate a value, this parameter defaults to “technical.”

    The AWS Support API does not currently support the ability to add attachments to cases. You can, however, call `AddCommunicationToCase`_ to add information to an open case.

    A successful `CreateCase`_ request returns an AWS Support case number. Case numbers are used by `DescribeCases`_ request to retrieve existing AWS Support support cases.

    Parameters: | subject (string) – Title of the AWS Support case. service_code (string) – Code for the AWS service returned by the call to `DescribeServices`_. severity_code (string) –

    Code for the severity level returned by the call to
      `DescribeSeverityLevels`_.
    The availability of severity levels depends on each customer’s support
      subscription. In other words, your subscription may not necessarily require the urgent level of response time.

    Parameters: | category_code (string) – Specifies the category of problem for the AWS Support case. communication_body (string) – Parameter that represents the communication body text when you create an AWS Support case by calling `CreateCase`_. cc_email_addresses (list) – List of email addresses that AWS Support copies on case correspondence. language (string) – Specifies the ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English and Japanese, for which the codes are en and ja , respectively. Language parameters must be passed explicitly for operations that take them. issue_type (string) – Field passed as a parameter in a `CreateCase`_ call.

  `describe_cases`(case_id_list=None, display_id=None, after_time=None, before_time=None, include_resolved_cases=None, next_token=None, max_results=None, language=None)

    This action returns a list of cases that you specify by passing one or more CaseIds. In addition, you can filter the cases by date by setting values for the AfterTime and BeforeTime request parameters. The response returns the following in JSON format:

    1. One or more `CaseDetails`_ data types.
    2. One or more NextToken objects, strings that specifies where to paginate the returned records represented by CaseDetails .

    Parameters: | case_id_list (list) – A list of Strings comprising ID numbers for support cases you want returned. The maximum number of cases is 100. display_id (string) – String that corresponds to the ID value displayed for a case in the AWS Support Center user interface. after_time (string) – Start date for a filtered date search on support case communications. before_time (string) – End date for a filtered date search on support case communications. include_resolved_cases (boolean) – Boolean that indicates whether or not resolved support cases should be listed in the `DescribeCases`_ search. next_token (string) – Defines a resumption point for pagination. max_results (integer) – Integer that sets the maximum number of results to return before paginating. language (string) – Specifies the ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English and Japanese, for which the codes are en and ja , respectively. Language parameters must be passed explicitly for operations that take them.

  `describe_communications`(case_id, before_time=None, after_time=None, next_token=None, max_results=None)

    This action returns communications regarding the support case. You can use the AfterTime and BeforeTime parameters to filter by date. The CaseId parameter enables you to identify a specific case by its CaseId number.

    The MaxResults and NextToken parameters enable you to control the pagination of the result set. Set MaxResults to the number of cases you want displayed on each page, and use NextToken to specify the resumption of pagination.

    Parameters: | case_id (string) – String that indicates the AWS Support caseID requested or returned in the call. The caseID is an alphanumeric string formatted as shown in this example CaseId: case-12345678910-2013-c4c1d2bf33c5cf47 before_time (string) – End date for a filtered date search on support case communications. after_time (string) – Start date for a filtered date search on support case communications. next_token (string) – Defines a resumption point for pagination. max_results (integer) – Integer that sets the maximum number of results to return before paginating.

  `describe_services`(service_code_list=None, language=None)

    Returns the current list of AWS services and a list of service categories that applies to each one. You then use service names and categories in your `CreateCase`_ requests. Each AWS service has its own set of categories.

    The service codes and category codes correspond to the values that are displayed in the Service and Category drop- down lists on the AWS Support Center `Open a new case`_ page. The values in those fields, however, do not necessarily match the service codes and categories returned by the DescribeServices request. Always use the service codes and categories obtained programmatically. This practice ensures that you always have the most recent set of service and category codes.

    Parameters: | service_code_list (list) – List in JSON format of service codes available for AWS services. language (string) – Specifies the ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English and Japanese, for which the codes are en and ja , respectively. Language parameters must be passed explicitly for operations that take them.

  `describe_severity_levels`(language=None)

    This action returns the list of severity levels that you can assign to an AWS Support case. The severity level for a case is also a field in the `CaseDetails`_ data type included in any `CreateCase`_ request.

    Parameters: | language (string) – Specifies the ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English and Japanese, for which the codes are en and ja , respectively. Language parameters must be passed explicitly for operations that take them.

  `describe_trusted_advisor_check_refresh_statuses`(check_ids)

    Returns the status of all refresh requests Trusted Advisor checks called using `RefreshTrustedAdvisorCheck`_.

    Parameters: | check_ids (list) – List of the CheckId values for the Trusted Advisor checks for which you want to refresh the status. You obtain the CheckId values by calling `DescribeTrustedAdvisorChecks`_.

  `describe_trusted_advisor_check_result`(check_id, language=None)

    This action responds with the results of a Trusted Advisor check. Once you have obtained the list of available Trusted Advisor checks by calling `DescribeTrustedAdvisorChecks`_, you specify the CheckId for the check you want to retrieve from AWS Support.

    The response for this action contains a JSON-formatted `TrustedAdvisorCheckResult`_ object , which is a container for the following three objects:

    1. `TrustedAdvisorCategorySpecificSummary`_
    2. `TrustedAdvisorResourceDetail`_
    3. `TrustedAdvisorResourcesSummary`_

    In addition, the response contains the following fields:

    1. Status. Overall status of the check.
    2. Timestamp. Time at which Trusted Advisor last ran the check.
    3. CheckId. Unique identifier for the specific check returned by the request.

    Parameters: | check_id (string) – language (string) – Specifies the ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English and Japanese, for which the codes are en and ja , respectively. Language parameters must be passed explicitly for operations that take them.

  `describe_trusted_advisor_check_summaries`(check_ids)

    This action enables you to get the latest summaries for Trusted Advisor checks that you specify in your request. You submit the list of Trusted Advisor checks for which you want summaries. You obtain these CheckIds by submitting a `DescribeTrustedAdvisorChecks`_ request.

    The response body contains an array of `TrustedAdvisorCheckSummary`_ objects.

    Parameters: | check_ids (list) – Unique identifier for a Trusted Advisor check.

  `describe_trusted_advisor_checks`(language)

    This action enables you to get a list of the available Trusted Advisor checks. You must specify a language code. English (“en”) and Japanese (“jp”) are currently supported. The response contains a list of `TrustedAdvisorCheckDescription`_ objects.

    Parameters: | language (string) – Specifies the ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English and Japanese, for which the codes are en and ja , respectively. Language parameters must be passed explicitly for operations that take them.

  `make_request`(action, body)
  `refresh_trusted_advisor_check`(check_id)

    This action enables you to query the service to request a refresh for a specific Trusted Advisor check. Your request body contains a CheckId for which you are querying. The response body contains a `RefreshTrustedAdvisorCheckResult`_ object containing Status and TimeUntilNextRefresh fields.

    Parameters: | check_id (string) –

  `resolve_case`(case_id=None)

    Takes a CaseId and returns the initial state of the case along with the state of the case after the call to `ResolveCase`_ completed.

    Parameters: | case_id (string) – String that indicates the AWS Support caseID requested or returned in the call. The caseID is an alphanumeric string formatted as shown in this example CaseId: case-12345678910-2013-c4c1d2bf33c5cf47

## boto.support.exceptions

exception `boto.support.exceptions.` `CaseCreationLimitExceeded`(status, reason, body=None, *args)

exception `boto.support.exceptions.` `CaseIdNotFound`(status, reason, body=None, *args)

exception `boto.support.exceptions.` `InternalServerError`(status, reason, body=None, *args)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.21.1 »